==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/customer/AddSetTopBoxToAccount.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.customer;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for addSetTopBoxToAccount complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="addSetTopBoxToAccount">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="arg0" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="arg1" type="{http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/}setTopBox" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "addSetTopBoxToAccount", propOrder = {
    "arg0",
    "arg1"
})
public class AddSetTopBoxToAccount {

    protected String arg0;
    protected SetTopBox arg1;

    /**
     * Gets the value of the arg0 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getArg0() {
        return arg0;
    }

    /**
     * Sets the value of the arg0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setArg0(String value) {
        this.arg0 = value;
    }

    /**
     * Gets the value of the arg1 property.
     * 
     * @return
     *     possible object is
     *     {@link SetTopBox }
     *     
     */
    public SetTopBox getArg1() {
        return arg1;
    }

    /**
     * Sets the value of the arg1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link SetTopBox }
     *     
     */
    public void setArg1(SetTopBox value) {
        this.arg1 = value;
    }

}

==> tv_9.2501-2602181641.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/customer/AddSetTopBoxToAccount.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.customer;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for addSetTopBoxToAccount complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="addSetTopBoxToAccount">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="arg0" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="arg1" type="{http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/}setTopBox" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "addSetTopBoxToAccount", propOrder = {
    "arg0",
    "arg1"
})
public class AddSetTopBoxToAccount {

    protected String arg0;
    protected SetTopBox arg1;

    /**
     * Gets the value of the arg0 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getArg0() {
        return arg0;
    }

    /**
     * Sets the value of the arg0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setArg0(String value) {
        this.arg0 = value;
    }

    /**
     * Gets the value of the arg1 property.
     * 
     * @return
     *     possible object is
     *     {@link SetTopBox }
     *     
     */
    public SetTopBox getArg1() {
        return arg1;
    }

    /**
     * Sets the value of the arg1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link SetTopBox }
     *     
     */
    public void setArg1(SetTopBox value) {
        this.arg1 = value;
    }

}
